/*
 * main.cpp
 *
 * Copyright (C) 2021  Emanoil Kotsev <deloptes@gmail.com>
 *
 *
 *  This file is part of kdbusnotification.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include <tdecmdlineargs.h>
#include <tdeaboutdata.h>
#include <tdemessagebox.h>

#include "NotificationDaemon.h"

int
main(int argc, char **argv)
{
    TDEAboutData aboutData(
            "notification-daemon-tde",
            I18N_NOOP("TDE DBUS Notification Daemon"),
            "0.1",
            I18N_NOOP("A DBUS notification to TDE interface."), // description
            TDEAboutData::License_GPL,
            "(c) 2021, Emanoil Kotsev",
            I18N_NOOP("TDE DBUS Notification Daemon"), // message
            0 /* TODO: Website */,
            "deloptes@gmail.com");

    TDECmdLineArgs::init( argc, argv, &aboutData );
//    TODO handle options if needed
//    TDECmdLineArgs::addCmdLineOptions( options );
//    KUniqueApplication::addCmdLineOptions();

    if (!KUniqueApplication::start())
    {
        tqDebug(i18n("notification-daemon-tde is already running.\n").local8Bit());
        return 0;
    }

    NotificationDaemon app;
    app.disableSessionManagement();

    if (!app.isConnectedToDBUS())
    {
        KMessageBox::error(NULL,i18n("Can't connect to DBus!"));
        // debug message for testing
        tqDebug(i18n("Can't connect to DBus!\n").local8Bit());
        KUniqueApplication::kApplication()->quit();
        return -1;
    }
    else
    {
        return app.exec();
    }
}
