/*
 *
 *  Notification DBus Service implementation
 *
 *  Copyright (C) 2021  Emanoil Kotsev <deloptes@gmail.com>
 *
 *  This file is part of kdbusnotification.
 *
 *  kdbusnotification is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  kdbusnotification is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with kdbusnotification; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
#ifndef NOTIFICATIONSNODEERVICE_H
#define NOTIFICATIONSNODEERVICE_H

#include <tqmap.h>
#include <tqdbusconnection.h>

#include "notificationsNode.h"
#include "dbusbaseNode.h"

/**
 * RootNodeService
 *  Service: -
 *  Path   : /
 *  Children: org
 */
class RootNodeService : public DBusBaseNode
{
public:
    RootNodeService(TQT_DBusConnection&);
    ~RootNodeService();
protected:
    virtual TQT_DBusObjectBase* createInterface(const TQString&);
private:
    TQMap<TQString, TQT_DBusObjectBase*> mInterfaces;
    TQT_DBusConnection mConnection;
};

/**
 * OrgNodeService
 *  Service: -
 *  Path   : /org
 *  Children: freedesktop
 */
class OrgNodeService : public DBusBaseNode
{
public:
    OrgNodeService(TQT_DBusConnection&);
    ~OrgNodeService();
protected:
    virtual TQT_DBusObjectBase* createInterface(const TQString&);
private:
    TQMap<TQString, TQT_DBusObjectBase*> mInterfaces;
    TQT_DBusConnection mConnection;
};

/**
 * FreeDesktopNodeService
 *  Service: -
 *  Path   : /org/freedesktop
 *  Children: notifications
 */
class FreeDesktopNodeService : public DBusBaseNode
{
public:
    FreeDesktopNodeService(TQT_DBusConnection&);
    ~FreeDesktopNodeService();
protected:
    virtual TQT_DBusObjectBase* createInterface(const TQString&);
private:
    TQMap<TQString, TQT_DBusObjectBase*> mInterfaces;
    TQT_DBusConnection mConnection;
};

/*
 * NotificationsNodeService
 *  Service: org.freedesktop.DBus.Introspectable
 *  Path   : /org/freedesktop/Notifications
 *  Children: -
 */
class NotificationsNodeService : public org::freedesktop::NotificationsNode
{
public:
    NotificationsNodeService(TQT_DBusConnection&);
    ~NotificationsNodeService();

protected:
    virtual TQT_DBusObjectBase* createInterface(const TQString&);

private:
    TQMap<TQString, TQT_DBusObjectBase*> mInterfaces;
    TQT_DBusConnection mConnection;
};


#endif // NOTIFICATIONSNODEERVICE_H
